@@ -7,7 +7,7 @@ use benimator::*;
 fn main() {
     App::new()
         .add_plugins(DefaultPlugins)
-        .add_plugin(AnimationPlugin) // <-- Add the plugin
+        .add_plugin(AnimationPlugin::default()) // <-- Add the plugin
         .add_startup_system(spawn.system())
         .run();
 }
